0.1.3
-----

- Update PyPI credentials; functionally identical to ``0.1.0-0.1.2``.

0.1.2
-----

- Functionally identical to ``0.1.0-0.1.1``, but actually updates ``setup.py``.

0.1.1
-----

- Ensure that manifest accounts for ``CHANGELOG.rst``.

0.1.0
-----

- Initial release.
